changeset 3371:76aeac001089

allow for new jtreg naming convention for patches
author jjg
date Thu, 05 Nov 2015 10:49:43 -0800
parents 755579d808dc
children 2c1838c6e03c
files test/tools/lib/ToolBox.java
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/test/tools/lib/ToolBox.java	Thu Nov 05 10:49:06 2015 -0800
+++ b/test/tools/lib/ToolBox.java	Thu Nov 05 10:49:43 2015 -0800
@@ -1665,9 +1665,9 @@
         private final Pattern jrtEntry = Pattern.compile("/modules/([^/]+)/(.*)");
 
         /*
          * A file: URL is of the form  file:/path/to/modules/<module>/<package>/<file>
          */
-        private final Pattern fileEntry = Pattern.compile(".*/modules/([^/]+)/(.*)");
+        private final Pattern fileEntry = Pattern.compile(".*/(modules|patches)/([^/]+)/(.*)");
 
         private String guessPath(FileObject fo) {
             URI u = fo.toUri();
@@ -1665,9 +1665,9 @@
 
         /*
-         * A file: URL is of the form  file:/path/to/modules/<module>/<package>/<file>
+         * A file: URL is of the form  file:/path/to/{modules,patches}/<module>/<package>/<file>
          */